
#include <Standard_SStream.hxx>
#include <Standard_Type.hxx>

Handle_Standard_Type& Standard_SStream_Type_() 
{
  static Handle_Standard_Type _aType = 
    new Standard_Type("Standard_SStream", sizeof(Standard_SStream));
  
  return _aType;
}

Standard_SStream::~Standard_SStream()
{
}

Standard_SStream::Standard_SStream(ostream& aStream)
{
  operator<<(aStream.rdbuf());
}

Standard_SStream::Standard_SStream()
{
}

ostream& operator<< (ostream& anOstream, Standard_SStream& aSStream)
{
  aSStream << ends;
  anOstream << GetSString (aSStream);
  return anOstream;
}
